# pyvacy - a set of access control decorators for python

## Usage

## Philosophy

* Incur as least overhead as possible when using the access control decorators 

## Current limitations

* `@private` and `@protected` are not supported on nested classes yet.

* No way to enforce access policy on class and instance attributes.

## Roadmap

* Benchmark decorated classes

* Test comprehensively the decorators interaction with the whole ecosystem

* Implement @private and @protected on nested classes

